==> haskell-toml-parser-2.0.1.2-62.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 toml-parser
version:              2.0.1.2
visibility:           public
id:                   toml-parser-2.0.1.2-L9EmAD8S0A46V7Jh42bR9n
key:                  toml-parser-2.0.1.2-L9EmAD8S0A46V7Jh42bR9n
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  74a022a82e8ce5a3f6b2161bc946bad8
exposed:              True
exposed-modules:
    Toml Toml.Pretty Toml.Schema Toml.Schema.FromValue
    Toml.Schema.Generic Toml.Schema.Generic.FromValue
    Toml.Schema.Generic.ToValue Toml.Schema.Matcher
    Toml.Schema.ParseTable Toml.Schema.ToValue Toml.Semantics
    Toml.Semantics.Ordered Toml.Semantics.Types Toml.Syntax
    Toml.Syntax.Lexer Toml.Syntax.Parser Toml.Syntax.Position
    Toml.Syntax.Token Toml.Syntax.Types

hidden-modules:       Toml.Syntax.LexerUtils Toml.Syntax.ParserUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-2.0.1.2-L9EmAD8S0A46V7Jh42bR9n
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo text-2.0.2 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-toml-parser-2.0.1.2-63-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 toml-parser
version:              2.0.1.2
visibility:           public
id:                   toml-parser-2.0.1.2-KrsTcuW1U9p5Sics2FJD9Y
key:                  toml-parser-2.0.1.2-KrsTcuW1U9p5Sics2FJD9Y
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  73810eb7c01b5b0840f7dc98aaaf2ec6
exposed:              True
exposed-modules:
    Toml Toml.Pretty Toml.Schema Toml.Schema.FromValue
    Toml.Schema.Generic Toml.Schema.Generic.FromValue
    Toml.Schema.Generic.ToValue Toml.Schema.Matcher
    Toml.Schema.ParseTable Toml.Schema.ToValue Toml.Semantics
    Toml.Semantics.Ordered Toml.Semantics.Types Toml.Syntax
    Toml.Syntax.Lexer Toml.Syntax.Parser Toml.Syntax.Position
    Toml.Syntax.Token Toml.Syntax.Types

hidden-modules:       Toml.Syntax.LexerUtils Toml.Syntax.ParserUtils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/toml-parser-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-2.0.1.2-KrsTcuW1U9p5Sics2FJD9Y
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ text-2.0.2 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
